.. include:: ../../README.rst

Document Overview
-----------------

This document describes the tools for final user and contributors of the
project, and assumes that you are already familiar with OpenStack from an
end-user perspective. If not, hop over to the
`OpenStack doc site <https://docs.openstack.org/>`__.

You can look for additional documentation also in the
`OpenStack wiki <http://wiki.openstack.org/>`__.

This documentation is generated by the Sphinx toolkit and lives in the `source
tree <https://opendev.org/x/tobiko/src/branch/master/doc/source>`__.

Enjoy!

.. include:: contents.rst
